<?php
/**
 * Plugin Name: Xeroom - Woocommerce to Xero Accounts Synch
 * Plugin URI:  https://www.xeroom.com/
 * Description: Enables sales orders and associated data to be automatically posted to Xero to create new sales invoices, credit notes and applied payments. This avoids rekeying of data and enables up-to-date, accurate, easy bookkeeping and accounting.
 * Version:     Xeroom 2.2.2
 * Author:      Peter Lloyd
 * Author URI:  https://www.xeroom.com/
 */

delete_transient( 'xeroom_update_xeroom' );
 
include_once( 'index-file.php' );

register_activation_hook( __FILE__, 'xeroom_master_install' );
register_uninstall_hook( 'uninstall.php', 'xeroom_master_uninstall' );

add_filter( 'plugin_row_meta', 'xeroom_plugin_row_meta', 10, 2 );
/**
 * @param $links
 * @param $file
 *
 * @return array
 */
function xeroom_plugin_row_meta( $links, $file ) {
	if ( plugin_basename( __FILE__ ) !== $file ) {
		return $links;
	}

	$row_meta = array(
		'support'      => '<a href="' . esc_url( apply_filters( 'xeroom_support_url', 'https://www.xeroom.com/support/' ) ) . '" aria-label="' . esc_attr__( 'Xeroom support', 'xeroom' ) . '">' . esc_html__( 'Support', 'xeroom' ) . '</a>',
        'view-details' => sprintf( '<a href="%s" class="thickbox" title="%s">%s</a>',
			self_admin_url( 'plugin-install.php?tab=plugin-information&amp;plugin=xeroom&amp;TB_iframe=true&amp;width=600&amp;height=550' ),
			esc_attr( sprintf( __( 'More information about %s' ), 'Xeroom' ) ),
			__( 'View Details' )
		),
	);

	return array_merge( $links, $row_meta );
}

add_filter( 'plugins_api', 'xeroom_plugin_info', 20, 3 );
/**
 * @param $res
 * @param $action
 * @param $args
 *
 * @return false|stdClass
 */
function xeroom_plugin_info( $res, $action, $args ) {
	if ( 'plugin_information' !== $action ) {
		return false;
	}

	$plugin_slug = 'xeroom';

	// do nothing if it is not our plugin
	if ( $plugin_slug !== $args->slug ) {
		return false;
	}

	// trying to get from cache first
	if ( false == $remote = get_transient( 'xeroom_update_' . $plugin_slug ) ) {
		// xeroom.json is the file with the actual plugin information on your server
		$remote = wp_remote_get( 'https://www.xeroom.com/wp-content/uploads/xeroom.json', array(
				'timeout' => 10,
				'headers' => array(
					'Accept' => 'application/json',
				),
			)
		);

		if ( ! is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && ! empty( $remote['body'] ) ) {
			set_transient( 'xeroom_update_' . $plugin_slug, $remote, 120 ); // 12 hours cache
		}
	}

	if ( ! is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && ! empty( $remote['body'] ) ) {
		$remote = json_decode( $remote['body'] );
		$res    = new stdClass();

		$res->name           = 'Xeroom';
		$res->slug           = $plugin_slug;
		$res->version        = $remote->version;
		$res->tested         = $remote->tested;
		$res->requires       = $remote->requires;
		$res->author         = '<a href="https://www.xeroom.com/">Xeroom</a>';
		$res->author_profile = 'https://www.xeroom.com/';
		$res->download_link  = $remote->download_url;
		$res->trunk          = $remote->download_url;
		$res->requires_php   = '7.2';
		$res->last_updated   = $remote->last_updated;
		$res->sections       = array(
			'description'  => $remote->sections->description,
			'installation' => $remote->sections->installation,
			'changelog'    => $remote->sections->changelog,
		);

		$res->banners = array(
			'low'  => 'https://www.xeroom.com/wp-content/uploads/xeroom/xeroom_hero_diagram.png',
			'high' => 'https://www.xeroom.com/wp-content/uploads/xeroom/xeroom_hero_diagram.png',
		);

		return $res;
	}

	return false;
}

add_filter( 'pre_set_site_transient_update_plugins', 'xeroom_push_update', 50 );
add_filter( 'site_transient_update_plugins', 'xeroom_push_update', 50 );
/**
 * @param $transient
 *
 * @return mixed
 */
function xeroom_push_update( $transient ) {
	if ( empty( $transient->checked ) ) {
		return $transient;
	}

	if ( false == $remote = get_transient( 'xeroom_update_xeroom' ) ) {
		// info.json is the file with the actual plugin information on your server
		$remote = wp_remote_get( 'https://www.xeroom.com/wp-content/uploads/xeroom.json', array(
				'timeout' => 10,
				'headers' => array(
					'Accept' => 'application/json',
				),
			)
		);

		if ( ! is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && ! empty( $remote['body'] ) ) {
			set_transient( 'xeroom_update_xeroom', $remote, 120 ); // 12 hours cache
		}
	}

	if ( $remote && ! is_wp_error( $remote ) ) {
		$remote = json_decode( $remote['body'] );
		// your installed plugin version should be on the line below! You can obtain it dynamically of course
		if ( $remote && version_compare( '2.2.2', $remote->version, '<' ) && version_compare( $remote->requires, get_bloginfo( 'version' ), '<' ) ) {
			$res                                 = new stdClass();
			$res->slug                           = 'xeroom';
			$res->plugin                         = 'xeroom/index.php';
			$res->new_version                    = $remote->version;
			$res->tested                         = $remote->tested;
			$res->package                        = $remote->download_url;
			$transient->response[ $res->plugin ] = $res;
			$transient->checked[ $res->plugin ]  = $remote->version;
		}
	}

	return $transient;
}

add_action( 'upgrader_process_complete', 'xeroom_after_update', 10, 2 );
/**
 * @param $upgrader_object
 * @param $options
 */
function xeroom_after_update( $upgrader_object, $options ) {
	if ( $options['action'] == 'update' && $options['type'] === 'plugin' ) {
		delete_transient( 'xeroom_update_xeroom' );
	}
}
